---
hide:
  - toc
---

<figure markdown="span">
  ![The Matchbox logo in light mode](./assets/matchbox-logo-light.svg#only-light){ width="500" }
  ![The Matchbox logo in dark mode](./assets/matchbox-logo-dark.svg#only-dark){ width="500" }
</figure>

<div class="grid cards" markdown>

- :material-run-fast:{ .lg .middle } **Getting started**

    ---

    Learn how to quickly install and use Matchbox:
    
    * The **client** lets you query and link/dedupe data
    * The **server** is for setting up a new Matchbox instance for your organisation.

    [:octicons-zap-16: Get started with the client](./client/install.md){ .md-button .md-button--primary } [:octicons-download-16: Deploy server in your org](./server/install.md){ .md-button .md-button--primary }

</div>

Record matching is a chore. Matchbox is a match pipeline orchestration tool that aims to:

* Make matching an iterative, collaborative, measurable problem
* Allow organisations to know they have matching records without having to share the data
* Allow matching pipelines to run iteratively
* Support batch and real-time matching 

Matchbox doesn't store raw data, instead indexing the data in your warehouse and leaving permissioning at the level of the user, service or pipeline. 
